@@ -1,7 +1,5 @@
 use crate::{async_trait, Conn, Info, Upgrade};
-use std::borrow::Cow;
-use std::future::Future;
-use std::sync::Arc;
+use std::{borrow::Cow, future::Future, sync::Arc};
 
 /**
 # The building block for Trillium applications.
@@ -288,13 +286,6 @@ where
     }
 }
 
-#[async_trait]
-impl Handler for String {
-    async fn run(&self, conn: Conn) -> Conn {
-        conn.ok(&self[..])
-    }
-}
-
 #[async_trait]
 impl Handler for &'static str {
     async fn run(&self, conn: Conn) -> Conn {
@@ -316,7 +307,7 @@ impl Handler for () {
 #[async_trait]
 impl<H: Handler> Handler for Option<H> {
     async fn run(&self, conn: Conn) -> Conn {
-        let handler = crate::conn_unwrap!(conn, self);
+        let handler = crate::conn_unwrap!(self, conn);
         handler.run(conn).await
     }
 
@@ -327,7 +318,7 @@ impl<H: Handler> Handler for Option<H> {
     }
 
     async fn before_send(&self, conn: Conn) -> Conn {
-        let handler = crate::conn_unwrap!(conn, self);
+        let handler = crate::conn_unwrap!(self, conn);
         handler.before_send(conn).await
     }
 
